pub fn current_execution_context() -> Option<ForgeContext>Expand description
Returns the current forge execution context, if it has been set.
pub fn current_execution_context() -> Option<ForgeContext>Returns the current forge execution context, if it has been set.